ipsec whack --impair suppress-retransmits
ipsec auto --up road-eastnet-psk
echo done
